@@ -47,21 +47,21 @@ class UFloat(ValueObject):
 class UStr(ValueObject):
     def __init__(self, value=None):
         if not isinstance(value, str):
-            raise TypeError('Value should be str type')
+            raise TypeError(f'Value should be str type, but {type(value)} is given: {value}')
         super().__init__(value)
 
 
 class UDict(ValueObject):
     def __init__(self, value=None):
         if not isinstance(value, dict):
-            raise TypeError('Value should be dict type')
+            raise TypeError(f'Value should be dict type, but {type(value)} is given: {value}')
         super().__init__(value)
 
 
 class UBool(ValueObject):
     def __init__(self, value=None):
         if not isinstance(value, bool):
-            raise TypeError('Value should be bool type')
+            raise TypeError(f'Value should be bool type, but {type(value)} is given: {value}')
         super().__init__(value)
 
 
@@ -70,7 +70,7 @@ class UDate(ValueObject):
         if value is None:
             value = datetime.datetime.utcnow()
         if not isinstance(value, datetime.datetime):
-            raise ValueError('Value should be datetime type')
+            raise ValueError(f'Value should be datetime type, but {type(value)} is given: {value}')
         super().__init__(value)
 
     def __str__(self) -> str:
